@@ -6,7 +6,7 @@ use DBIx::Class::ResultClass::HashRefInflator;
 use Lingua::EN::Inflect::Phrase;
 use String::CamelCase qw(camelize);
 
-our $VERSION = '0.400';
+our $VERSION = '0.401';
 
 =head1 NAME 
 
@@ -396,6 +396,8 @@ sub set_user_details {
         }
     }
     $user->update({%update});
+    # Update $username if it was submitted in update
+    $username = $update{username} if $update{username};
     return $self->get_user_details($username);
 }
 
